@@ -28,9 +28,9 @@ class OpenAIAnswerGenerator(BaseGenerator):
         self,
         api_key: str,
         model: str = "text-curie-001",
-        max_tokens: int = 7,
+        max_tokens: int = 13,
         top_k: int = 5,
-        temperature: int = 0,
+        temperature: float = 0.2,
         presence_penalty: float = -2.0,
         frequency_penalty: float = -2.0,
         examples_context: Optional[str] = None,
